import pytest
from orchestrator.types import SubscriptionLifecycle

from gso.products import ProductName
from gso.products.product_types.site import Site
from gso.products.product_types.super_pop_switch import ImportedSuperPopSwitch
from test.workflows import (
    assert_complete,
    extract_state,
    run_workflow,
)


@pytest.fixture()
def workflow_input_data(faker, site_subscription_factory):
    return {
        "partner": "GEANT",
        "hostname": faker.domain_word(),
        "super_pop_switch_site": Site.from_subscription(site_subscription_factory()).site.site_name,
        "super_pop_switch_ts_port": faker.port_number(is_user=True),
        "super_pop_switch_mgmt_ipv4_address": faker.ipv4(),
    }


@pytest.mark.workflow()
def test_create_imported_office_router_success(workflow_input_data):
    result, _, _ = run_workflow("create_imported_super_pop_switch", [workflow_input_data])
    state = extract_state(result)
    imported_super_pop_switch = ImportedSuperPopSwitch.from_subscription(state["subscription_id"])

    assert_complete(result)
    assert imported_super_pop_switch.product.name == ProductName.IMPORTED_SUPER_POP_SWITCH
    assert imported_super_pop_switch.status == SubscriptionLifecycle.ACTIVE
